# Acknowledgements

Maintainers:

- Richard S. ([@ichard26](https://github.com/ichard26))

Blackbench also sees outside contributions whose contributors I greatly appreciate. A
list of all contributors can be found on the
[repo's insights page](https://github.com/ichard26/blackbench/graphs/contributors).

Finally, this project wouldn't have existed if it wasn't for {pypi}`black` which I help
to maintain. Thank you goes to all maintainers and contributors to Black, for both the
great tool and this fun project!
